@@ -2,7 +2,7 @@
 #[allow(unused_variables)]
 #[allow(unused_imports)]
 #[allow(dead_code)]
-mod cornucopia_gen;
+mod cornucopia;
 #[allow(clippy::all)]
 #[allow(unused_variables)]
 #[allow(unused_imports)]
